Crate intid_derive

Crate intid_derive 

Implements the IntegerId derive macro.

Generally, you want to use the re-export from the intid or idmap crates. In the intid crate this requires explicitly enabling the derive feature. In the idmap crate, the derive feature is on by default.

Derive Macros

EnumId
See the documentation in the intid crate for details.
IntegerId
See the documentation in the intid crate for details.
IntegerIdContiguous
See intid crate for docs.
IntegerIdCounter
See intid crate for docs.