#[derive(IntegerId)]
{
// Attributes available to this derive:
#[intid]
}
See the documentation in the intid crate for details.
#[derive(IntegerId)]
{
// Attributes available to this derive:
#[intid]
}
See the documentation in the intid crate for details.