Implements the IntegerId derive macro.
Generally, you want to use the re-export from the intid or idmap crates.
In the intid crate this requires explicitly enabling the derive feature.
In the idmap crate, the derive feature is on by default.
Derive Macros
- EnumId
- See the documentation in the
intidcrate for details. - Integer
Id - See the documentation in the
intidcrate for details. - Integer
IdContiguous - See
intidcrate for docs. - Integer
IdCounter - See
intidcrate for docs.